@@ -208,7 +208,7 @@ cffi_ffierror simple_service_create(cffi_simpleservice** context_ptr, uint32_t x
 cffi_ffierror simple_service_destroy(cffi_simpleservice** context_ptr);
 cffi_ffierror simple_service_result(cffi_simpleservice* context_ptr, uint32_t x);
 uint32_t simple_service_value(cffi_simpleservice* context_ptr, uint32_t x);
-uint32_t simple_service_mut_self(cffi_simpleservice* context_ptr, uint32_t x);
+uint8_t simple_service_mut_self(cffi_simpleservice* context_ptr, cffi_ffisliceu8 slice);
 void simple_service_void(cffi_simpleservice* context_ptr);
 uint32_t simple_service_extra_method(cffi_simpleservice* _context);
 """
@@ -1110,14 +1110,14 @@ This function may only be called with a context returned by a succeeding `patter
             x = x._ctx[0]
         return _api.simple_service_value(context_ptr, x)
 
-    def simple_service_mut_self(context_ptr, x):
+    def simple_service_mut_self(context_ptr, slice):
         """"""
         global _api
         if hasattr(context_ptr, "_ctx"):
             context_ptr = context_ptr._ctx[0]
-        if hasattr(x, "_ctx"):
-            x = x._ctx[0]
-        return _api.simple_service_mut_self(context_ptr, x)
+        if hasattr(slice, "_ctx"):
+            slice = slice._ctx[0]
+        return _api.simple_service_mut_self(context_ptr, slice)
 
     def simple_service_void(context_ptr):
         """"""
@@ -1218,10 +1218,10 @@ class SimpleService(object):
         global raw
         return _api.simple_service_value(self.ctx[0], x)
 
-    def mut_self(self, x):
+    def mut_self(self, slice):
         """"""
         global raw
-        return _api.simple_service_mut_self(self.ctx[0], x)
+        return _api.simple_service_mut_self(self.ctx[0], slice)
 
     def void(self, ):
         """"""
